<?php
/*
Plugin Name: WPSE Custom Postal Codes
 * Plugin URI: https://softtron.net
 * Description: Este plugin controla comprar solo si es valido el codigo postal.
 * Version: 1.0.0
 * Author: Daniel Romero - Softtron Net
 * Author URI: https://softtron.net
License: GPL2
*/

function wpse_check_custom_postal_codes( $can_purchase, $product_id, $quantity, $customer ) {
    // Obtiene el código postal introducido por el cliente
    $postal_code = $customer->get_shipping_postcode();
    
    // Si el cliente no tiene código postal de envío, no se puede comprar
    if ( empty( $postal_code ) ) {
        return false;
    }
    
    // Obtiene los códigos postales permitidos del producto
    $custom_postal_codes = get_post_meta( $product_id, '_custom_postcode_field', true );
    
    // Si no hay códigos postales permitidos en el producto, se puede comprar para cualquier código postal
    if ( empty( $custom_postal_codes ) ) {
        return true;
    }
    
    // Divide los códigos postales permitidos separados por comas o espacios
    $postal_codes_array = preg_split('/[\s,]+/', $custom_postal_codes);
    
    // Comprueba si el código postal del cliente está en el array de códigos permitidos
    $postal_code_allowed = false;
    foreach ( $postal_codes_array as $postal_code_range ) {
        // Si el código postal es un rango, comprueba si el código postal del cliente está dentro del rango
        if ( strpos( $postal_code_range, '...' ) !== false ) {
            $range = explode( '...', $postal_code_range );
            if ( $postal_code >= $range[0] && $postal_code <= $range[1] ) {
                $postal_code_allowed = true;
                break;
            }
        } else {
            // Si el código postal no es un rango, comprueba si coincide con el código postal permitido
            if ( $postal_code == $postal_code_range ) {
                $postal_code_allowed = true;
                break;
            }
        }
    }
    
    // Si el código postal no está permitido, no se puede comprar
    if ( !$postal_code_allowed ) {
        return false;
    }
    
    return $can_purchase;
}

add_filter( 'woocommerce_is_purchasable', 'wpse_check_custom_postal_codes', 10, 4 );
